netapp_ontap.models.fc_switch_port API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_switch_port`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcSwitchPortSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcSwitchPort object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `attached_device: FcSwitchPortsAttachedDevice GET`

    The Fibre Channel (FC) device attached to the FC switch port.

  `slot: str GET`

    The slot of the Fibre Channel switch port.

    Example: 1

  `state: str GET`

    The state of the Fibre Channel switch port.

    Valid choices:

    - unknown
    - online
    - offline
    - testing
    - fault
  `type: str GET`

    The type of the Fibre Channel switch port.

    Valid choices:

    - b_port
    - e_port
    - f_port
    - fl_port
    - fnl_port
    - fv_port
    - n_port
    - nl_port
    - nv_port
    - nx_port
    - sd_port
    - te_port
    - tf_port
    - tl_port
    - tnp_port
    - none
  `wwpn: str GET`

    The world wide port name (WWPN) of the Fibre Channel switch port.

    Example: 50:0a:31:32:33:34:35:36